==> ggalign_0.1.0.tar.gz: ggalign/tests/testthat/_snaps/plot-align.md <==
# `align_group` works well

    Cannot add `align_group(column_group)` to `ggheatmap()`
    i no active annotation stack
    i try to activate an annotation stack with `anno_*()`

---

    `group` (nobs: 4) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

---

    `group` (nobs: 9) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

---

    `group` (nobs: 4) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

---

    `group` (nobs: 9) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

# `align_order` works well

    Cannot add `align_order()` to the top annotation `stack_discrete()`
    i Group of the top annotation `stack_discrete()` will disrupt the ordering index of `align_order()`
    i try to set `strict = FALSE` to reorder within each group

---

    Cannot add `geom_point()` to `align_order()`
    i no plot found for `align_order()`

# `align_reorder` works well

    Cannot add `align_reorder()` to the top annotation `stack_discrete()`
    i Group of the top annotation `stack_discrete()` will disrupt the ordering index of `align_reorder()`
    i try to set `strict = FALSE` to reorder within each group

---

    Cannot add `geom_point()` to `align_reorder()`
    i no plot found for `align_reorder()`

# `align_kmeans` works well

    `align_kmeans()` disrupt the previously established panel groups of the top annotation `stack_discrete()`

---

    `align_kmeans()` disrupt the previously established panel groups of the left annotation `stack_discrete()`

---

    Cannot add `geom_point()` to `align_kmeans()`
    i no plot found for `align_kmeans()`

# `align_dendro` works well

    `align_dendro()` disrupt the previously established panel groups of the top annotation `stack_discrete()`

# `ggalign()` works well

    `coord_polar()` is not supported in the top annotation `stack_discrete()`
    i Will use `coord_cartesian()` instead

==> ggalign_1.0.2.tar.gz: ggalign/tests/testthat/_snaps/plot-align.md <==
# `align_group` works well

    Cannot add `align_group(column_group)` to `ggheatmap()`
    i no active annotation stack
    i try to activate an annotation stack with `anno_*()`

---

    `group` (nobs: 4) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

---

    `group` (nobs: 9) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

---

    `group` (nobs: 4) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

---

    `group` (nobs: 9) of `align_group()` is not compatible with the the top annotation `stack_discrete()` (nobs: 8)

# `align_order` works well

    Cannot add `align_order()` to the top annotation `stack_discrete()`
    i Group of the top annotation `stack_discrete()` will disrupt the ordering index of `align_order()`
    i try to set `strict = FALSE` to reorder within each group

---

    Cannot add `geom_point()` to `align_order()`
    i no plot found for `align_order()`

# `align_order2` works well

    Cannot add `align_order2()` to the top annotation `stack_discrete()`
    i Group of the top annotation `stack_discrete()` will disrupt the ordering index of `align_order2()`
    i try to set `strict = FALSE` to reorder within each group

---

    Cannot add `geom_point()` to `align_order2()`
    i no plot found for `align_order2()`

# `align_kmeans` works well

    `align_kmeans()` disrupt the previously established panel groups of the top annotation `stack_discrete()`

---

    `align_kmeans()` disrupt the previously established panel groups of the left annotation `stack_discrete()`

---

    Cannot add `geom_point()` to `align_kmeans()`
    i no plot found for `align_kmeans()`

# `align_dendro` works well

    `align_dendro()` disrupt the previously established panel groups of the top annotation `stack_discrete()`

# `ggalign()` works well

    `coord_polar()` is not supported in the top annotation `stack_discrete()`
    i Will use `coord_cartesian()` instead
